@@ -269,7 +269,7 @@ func TestStartImageScan(t *testing.T) {
 			wantErr: fmt.Errorf("error image scan waiting"),
 		},
 		{
-			name: "image scan started and complted successfully",
+			name: "image scan started and completed successfully",
 			fields: fields{
 				scanner: mockECRScanner{},
 			},
@@ -317,7 +317,7 @@ func TestECRScanImage(t *testing.T) {
 		wantErr bool
 	}{
 		{
-			name: "inavlid image reference",
+			name: "invalid image reference",
 			fields: fields{
 				scanner: mockECRScanner{},
 			},
